@@ -14,9 +14,14 @@ def main(args=None):
     app = '%(prog)s version ' + __version__
     parser.add_argument('-v', '--version', action='version', version=app)
     sub = parser.add_subparsers(dest='action', required=True, help='actions')
-    api.cli_options(sub)
-    package.cli_options(sub)
-    system.cli_options(sub)
-    account.cli_options(sub)
-    args = parser.parse_args(args)
-    args.func(args)
+
+    try:
+        api.cli_options(sub)
+        package.cli_options(sub)
+        system.cli_options(sub)
+        account.cli_options(sub)
+        args = parser.parse_args(args)
+        args.func(args)
+
+    except Exception:
+        sys.exit(1)
