@@ -8,7 +8,7 @@ from io import StringIO
 import responses
 from a28 import account, config, utils
 from a28.config import ConfigFile
-
+from a28.api import ApiError
 
 class TestAccountMethods(unittest.TestCase):
     def setUp(self) -> None:
@@ -141,8 +141,9 @@ authentication successful''',
         )
         self.assertEqual({}, ConfigFile.load())
 
-        with contextlib.redirect_stdout(self.temp_stdout):
-            account.authenticate(region="international", email="joe@example.com", password="123")
+        with self.assertRaises(ApiError):
+            with contextlib.redirect_stdout(self.temp_stdout):
+                account.authenticate(region="international", email="joe@example.com", password="123")
 
         self.assertEqual("error authenticating: you can't", self.temp_stdout.getvalue().strip())
         self.assertEqual({}, ConfigFile.load())
@@ -169,8 +170,9 @@ authentication successful''',
         )
         self.assertEqual({}, ConfigFile.load())
 
-        with contextlib.redirect_stdout(self.temp_stdout):
-            account.authenticate(region="international", email="joe@example.com", password="123")
+        with self.assertRaises(ApiError):
+            with contextlib.redirect_stdout(self.temp_stdout):
+                account.authenticate(region="international", email="joe@example.com", password="123")
 
         self.assertEqual("error authenticating: 500", self.temp_stdout.getvalue().strip())
         self.assertEqual({}, ConfigFile.load())
